summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qt_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qt_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qt_imp.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kjsembed/qtbindings/qt_imp.cpp b/kjsembed/qtbindings/qt_imp.cpp
index d7b2ed2e..899710f2 100644
--- a/kjsembed/qtbindings/qt_imp.cpp
+++ b/kjsembed/qtbindings/qt_imp.cpp
@@ -718,15 +718,15 @@ void QtImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
* Extract a Qt pointer from an Object.
*/
-Qt *QtImp::toQt( KJS::Object &self )
+TQt *QtImp::toTQt( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
TQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<Qt *>( obj );
+ return dynamic_cast<TQt *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
@@ -736,7 +736,7 @@ Qt *QtImp::toQt( KJS::Object &self )
if ( op->typeName() != "Qt" )
return 0;
- return op->toNative<Qt>();
+ return op->toNative<TQt>();
}
/**
@@ -757,7 +757,7 @@ KJS::Object QtImp::construct( KJS::ExecState *exec, const KJS::List &args )
KJS::Value QtImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
{
- instance = QtImp::toQt( self );
+ instance = QtImp::toTQt( self );
switch( id ) {
@@ -718,15 +718,15 @@ void QtImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a Qt pointer from an Object.
+ * Extract a TQt pointer from an Object.
*/